@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtselect.c 10173 2014-01-01 09:52:34Z pwessel $
+ *	$Id: gmtselect.c 10289 2014-12-28 21:17:06Z pwessel $
  *
- *	Copyright (c) 1991-2014 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -106,15 +106,14 @@ struct GMTSELECT_CTRL {	/* All control options for this program (except common a
 
 int main (int argc, char **argv)
 {
-	GMT_LONG i, j, k, fno, n_files = 0, n_args, err, n_minimum = 2;
+	GMT_LONG i, j, k, fno, n_files = 0, n_args, err = 0, n_minimum = 2;
 	GMT_LONG n_fields, n_expected_fields, ind, bin, last_bin = -1, n_output = -1;
 	GMT_LONG np[2], base = 3, wd[2], id, this_node, side, is_inside, row, col, pos;
 	GMT_LONG n_read = 0, n_pass = 0, no_resample = 0;
-
 	GMT_LONG error = FALSE, dry_wet_only = FALSE, long_verbose = FALSE, need_header, shuffle;
 	GMT_LONG cartesian = FALSE, nofile = TRUE, done = FALSE, first = TRUE, inside, plain_xy;
 	GMT_LONG greenwich = FALSE, output_header = FALSE, do_project = FALSE, just_copy_record = FALSE;
-
+	
 	double west = 0.0, east = 0.0, south = 0.0, north = 0.0, xx, yy;
 	double *in, west_border = 0.0, east_border = 0.0;
 	double xmin, xmax, ymin, ymax, lon, step = 0.0;
@@ -427,8 +426,8 @@ int main (int argc, char **argv)
 			Ctrl->N.mask[3] = Ctrl->N.mask[1];
 			Ctrl->N.mask[2] = Ctrl->N.mask[4] = Ctrl->N.mask[0];
 		}
-		if (GMT_init_shore (Ctrl->D.set, &c, west, east, south, north, &Ctrl->A.info)) {
-			fprintf (stderr, "%s: %s resolution shoreline data base not installed\n", GMT_program, shore_resolution[base]);
+		if ((err = GMT_init_shore (Ctrl->D.set, &c, west, east, south, north, &Ctrl->A.info))) {
+			fprintf (stderr, "%s: %s [GSHHG %s resolution shoreline]\n", GMT_program, GMT_strerror(err), shore_resolution[base]);
 			exit (EXIT_FAILURE);
 		}
 		if (gmtdefs.verbose == 2) fprintf (stderr, "GSHHS version %s\n%s\n%s\n", c.version, c.title, c.source);
@@ -602,9 +601,8 @@ int main (int argc, char **argv)
 				continue;
 			}
 
-			if (Ctrl->Z.active) {
-				if (GMT_is_dnan (in[GMT_Z])) { output_header = need_header; continue;}	/* cannot keep when no z */
-				inside = (in[GMT_Z] >= Ctrl->Z.min && in[GMT_Z] <= Ctrl->Z.max); 
+			if (Ctrl->Z.active) {	/* NaN is considered inside */
+				inside = (GMT_is_dnan (in[GMT_Z]) || (in[GMT_Z] >= Ctrl->Z.min && in[GMT_Z] <= Ctrl->Z.max)); 
 				if (inside != Ctrl->I.pass[5]) { output_header = need_header; continue;}
 			}
 
