@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcontour.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: grdcontour.c 10322 2015-10-07 13:38:30Z remko $
  *
  *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -114,7 +114,7 @@ int main (int argc, char **argv)
 {
 	GMT_LONG j, k, c, n_edges, n_alloc = 0, section, n_contours, id;
 	GMT_LONG nx, ny, n_save = 0, got, nm, i, n, nn, *edge = NULL;
-	
+
 	int rgb[3];
 
 	GMT_LONG error = FALSE, interior, begin;
@@ -141,11 +141,11 @@ int main (int argc, char **argv)
 	void GMT_grd_minmax (float *a, struct GRD_HEADER *h, double xyz[2][3]);
 	void adjust_hill_label (struct GMT_CONTOUR *G, struct GRD_HEADER *h, float *z);
 	void *New_grdcontour_Ctrl (), Free_grdcontour_Ctrl (struct GRDCONTOUR_CTRL *C);
-	
+
 	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDCONTOUR_CTRL *)New_grdcontour_Ctrl ();	/* Allocate and initialize a new control structure */
-	
+
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
@@ -492,7 +492,7 @@ int main (int argc, char **argv)
 	nm = GMT_get_nm (nx, ny);
 
 	/* Read data */
-	
+
 	grd_original = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 	GMT_err_fail (GMT_read_grd (grdfile, &header, grd_original, data_west, data_east, data_south, data_north, GMT_pad, FALSE), grdfile);
 
@@ -512,7 +512,7 @@ int main (int argc, char **argv)
 		GMT_end (argc, argv);
 		exit (EXIT_SUCCESS);
 	}
-	
+
 	small = Ctrl->C.interval * 1.0e-6;
 	if (Ctrl->A.interval == 0.0) Ctrl->A.interval = Ctrl->C.interval;
 
@@ -527,7 +527,7 @@ int main (int argc, char **argv)
 
 	if (Ctrl->C.cpt) {	/* Presumably got a cpt-file */
 		GMT_read_cpt (Ctrl->C.file);
-#ifdef GMT_CPT2	
+#ifdef GMT_CPT2
 		if (GMT_categorical) {
 			fprintf (stderr, "%s: GMT WARNING:  Categorical data (as implied by CPT file) does not have contours.  Check plot.\n", GMT_program);
 			exit (EXIT_FAILURE);
@@ -617,9 +617,9 @@ int main (int argc, char **argv)
 		GMT_end (argc, argv);
 		exit (EXIT_SUCCESS);
 	}
-	
+
 	/* OK, now we know we have contouring to do */
-	
+
 	(void)GMT_alloc_memory2 ((void **)&contour, (void **)&cont_angle, 0, n_contours, sizeof (double), GMT_program);
 	n_alloc = GMT_alloc_memory2 ((void **)&cont_type, (void **)&cont_do_tick, 0, n_contours, sizeof (char), GMT_program);
 
@@ -627,10 +627,10 @@ int main (int argc, char **argv)
 	if (GMT_contlabel_prep (&Ctrl->contour, xyz)) exit (EXIT_FAILURE);	/* Prep for crossing lines, if any */
 
 	for (i = 0; i < 3; i++) GMT_io.out_col_type[i] = GMT_io.in_col_type[i];	/* Used if -D is set */
-	
+
 	/* Because we are doing single-precision, we cannot subtract incrementally but must start with the
 	 * original grid values and subtract the current contour value. */
-	 
+
 	grd = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 	n_edges = header.ny * (int )ceil (header.nx / 16.0);
 	edge = (GMT_LONG *) GMT_memory (VNULL, (size_t)n_edges, sizeof (GMT_LONG), GMT_program);
@@ -638,7 +638,7 @@ int main (int argc, char **argv)
 #ifdef EXPERIMENT
 	wrap_check = (GMT_io.in_col_type[0] == GMT_IS_LON && (fabs (header.x_max - header.x_min - 360.0) < GMT_SMALL));
 #endif
-	
+
 	GMT_plotinit (argc, argv);
 	if (project_info.three_D) ps_transrotate (-z_project.xmin, -z_project.ymin, 0.0);
 
@@ -678,7 +678,7 @@ int main (int argc, char **argv)
 				interior = 3;
 				x[n-1] = x[0];	y[n-1] = y[0];	/* Ensure exact closure */
 			}
-#ifdef EXPERIMENT	
+#ifdef EXPERIMENT
 			else if (wrap_check) {
 				if (fabs (x[0] - header.x_min) < GMT_SMALL && fabs (x[n-1] - header.x_min) < GMT_SMALL) interior = 2;
 				else if (fabs (x[0] - header.x_max) < GMT_SMALL && fabs (x[n-1] - header.x_max) < GMT_SMALL) interior = 1;
@@ -719,7 +719,7 @@ int main (int argc, char **argv)
 		}
 	}
 
-	if (Ctrl->W.pen[0].texture || Ctrl->W.pen[1].texture) ps_setdash (CNULL, 0);
+	ps_setdash (CNULL, 0);
 
 	if (Ctrl->T.active && n_save) {
 		(void)GMT_alloc_memory ((void **)&save, 0, n_save, sizeof (struct SAVE), GMT_program);
@@ -732,9 +732,9 @@ int main (int argc, char **argv)
 		GMT_free ((void *)save);
 	}
 
-	
+
 	if (Ctrl->contour.hill_label) adjust_hill_label (&Ctrl->contour, &header, grd_original);	/* Must possibly adjust label angles so that label is readable when following contours */
-	
+
 	GMT_contlabel_plot (&Ctrl->contour);
 	GMT_contlabel_free (&Ctrl->contour);
 
@@ -771,7 +771,7 @@ void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, f
 	double x0, y0, add, sign, dx, dy, x_back, y_back, x_front, y_front;
 	double xmin, xmax, ymin, ymax, x_mean = 0.0, y_mean = 0.0, inc, dist, a, small, this_lon, this_lat, L, sa, ca, *s;
 	char txt[2][2];
-#ifdef EXPERIMENT	
+#ifdef EXPERIMENT
 	GMT_LONG k, m, reverse;
 #endif
 	/* The x/y coordinates in SAVE are now all projected to map inches */
@@ -790,9 +790,9 @@ void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, f
 		}
 	}
 
-#ifdef EXPERIMENT	
+#ifdef EXPERIMENT
 	/* Reconnect closed contours split at a periodic boundary */
-	
+
 	for (i = 0; i < n; i++) {	/* For all or these "closed" contours */
 		if (save[i].do_it == 3) continue;	/* This one is fully closed already */
 		for (j = i + 1; j < n; j++) {	/* Compare to all other "closed" contours */
@@ -826,7 +826,7 @@ void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, f
 		}
 	}
 #endif
-	
+
 	for (i = 0; i < n; i++) {	/* Mark polygons that have other polygons inside them */
 		np = save[i].n;
 		for (j = 0; save[i].do_it == 3 && j < n; j++) {
@@ -856,7 +856,7 @@ void sort_and_plot_ticks (struct SAVE *save, GMT_LONG n, struct GRD_HEADER *h, f
 		}
 
 		/* Pick the mid-latitude and march along that line from east to west */
-		
+
 		this_lat = 0.5 * (ymax + ymin);	/* Mid latitude, probably not exactly on a y-node */
 		iy = MIN (h->ny - 1, GMT_y_to_j (this_lat, h->y_min, h->y_inc, h->xy_off, h->ny));	/* Get closest j-row */
 		this_lat = GMT_j_to_y (iy, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny);		/* Get its matching latitude */
@@ -977,11 +977,11 @@ void GMT_grd_minmax (float *a, struct GRD_HEADER *h, double xyz[2][3])
 }
 
 void adjust_hill_label (struct GMT_CONTOUR *G, struct GRD_HEADER *h, float *z)
-{	
+{
 	GMT_LONG i, k, i0, j0;
 	double nx, ny, x_on, y_on, x_node, y_node, x_node_p, y_node_p, dx, dy, dz, dot, angle;
 	struct GMT_CONTOUR_LINE *C;
-	
+
 	for (i = 0; i < G->n_segments; i++) {
 		C = G->segment[i];	/* Pointer to current segment */
 		for (k = 0; k < C->n_labels; k++) {
@@ -1015,14 +1015,14 @@ void adjust_hill_label (struct GMT_CONTOUR *G, struct GRD_HEADER *h, float *z)
 		}
 	}
 }
-	
+
 void *New_grdcontour_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDCONTOUR_CTRL *C;
-	
+
 	C = (struct GRDCONTOUR_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDCONTOUR_CTRL), "New_grdcontour_Ctrl");
-	
+
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
-	
+
 	GMT_contlabel_init (&C->contour, 1);
 	C->D.file = strdup ("contour");
 	C->E.azimuth = 180.0;
@@ -1040,12 +1040,12 @@ void *New_grdcontour_Ctrl () {	/* Allocate and initialize a new control structur
 	GMT_init_pen (&C->W.pen[0], GMT_PENWIDTH);	/* Normal pen for contours and 3*thicker for annotated contours */
 	GMT_init_pen (&C->W.pen[1], 3.0 * GMT_PENWIDTH);
 	C->Z.scale = 1.0;
-	
+
 	return ((void *)C);
 }
 
 void Free_grdcontour_Ctrl (struct GRDCONTOUR_CTRL *C) {	/* Deallocate control structure */
-	if (C->C.file) free ((void *)C->C.file);	
-	if (C->D.file) free ((void *)C->D.file);	
-	GMT_free ((void *)C);	
+	if (C->C.file) free ((void *)C->C.file);
+	if (C->D.file) free ((void *)C->D.file);
+	GMT_free ((void *)C);
 }
