@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: grdimage.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: grdimage.c 10314 2015-06-11 06:18:34Z pwessel $
  *
  *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -318,6 +318,10 @@ int main (int argc, char **argv)
 #ifdef USE_GDAL
 	if (Ctrl->D.active) {} else
 #endif
+	if (n_grids == 0) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify 1 or 3 input grids\n", GMT_program);
+		error++;
+	}
 	if (!Ctrl->C.file && !do_rgb) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify color palette table\n", GMT_program);
 		error++;
