@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: grdview.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: grdview.c 10322 2015-10-07 13:38:30Z remko $
  *
  *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -36,7 +36,7 @@
  * Date:	17-SEP-2001
  * Version:	4
  */
- 
+
 #include "gmt.h"
 #include "pslib.h"
 
@@ -135,7 +135,7 @@ int main (int argc, char **argv)
 	GMT_LONG PS_colormask_off = 0, PS_colormask, n_commas, q_set = 0, two, way, *edge = NULL;
 
 	int rgb[3];
-	
+
 	float *grd[3], *zgrd = NULL, *intensity = NULL, *topo = NULL;
 
 	double cval, x_left, x_right, y_top, y_bottom, small = GMT_SMALL, z_ave, this_intensity = 0.0, *xval, *yval;
@@ -171,7 +171,7 @@ int main (int argc, char **argv)
 	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct GRDVIEW_CTRL *)New_grdview_Ctrl ();	/* Allocate and initialize a new control structure */
-	
+
 	topofile = CNULL;
 	GMT_3D_mode = 1;	/* Only do background axis first; do foreground at end */
 	grd[0] = grd[1] = grd[2] = (float *)NULL;
@@ -179,7 +179,7 @@ int main (int argc, char **argv)
 	GMT_grd_init (&t_head, argc, argv, FALSE);
 	GMT_grd_init (&i_head, argc, argv, FALSE);
 	for (i = 0; i < 3; i++) GMT_grd_init (&d_head[i], argc, argv, FALSE);
-	
+
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
@@ -406,12 +406,12 @@ int main (int argc, char **argv)
 		GMT_pen_syntax ('W', "sets pen attributes for various features in form <type><pen>.");
 		fprintf (stderr, "\t   <type> can be c for contours, m for mesh, and f for facade.\n");
 		fprintf (stderr, "\t   c draw scontours on top of surface or mesh [Default is no contours].\n");
-		fprintf (stderr, "\t     Optionally append pen attributes [width = %gp, color = (%d/%d/%d), solid line].\n", 
+		fprintf (stderr, "\t     Optionally append pen attributes [width = %gp, color = (%d/%d/%d), solid line].\n",
 			Ctrl->W.pen[0].width, Ctrl->W.pen[0].rgb[0], Ctrl->W.pen[0].rgb[1], Ctrl->W.pen[0].rgb[2]);
-		fprintf (stderr, "\t   m sets attributes for mesh lines [width = %gp, color = (%d/%d/%d), solid line].\n", 
+		fprintf (stderr, "\t   m sets attributes for mesh lines [width = %gp, color = (%d/%d/%d), solid line].\n",
 			Ctrl->W.pen[1].width, Ctrl->W.pen[1].rgb[0], Ctrl->W.pen[1].rgb[1], Ctrl->W.pen[1].rgb[2]);
 		fprintf (stderr, "\t     Requires -Qm or -Qsm to take effect.\n");
-		fprintf (stderr, "\t   f sets attributes for facade outline [width = %gp, color = (%d/%d/%d), solid line].\n", 
+		fprintf (stderr, "\t   f sets attributes for facade outline [width = %gp, color = (%d/%d/%d), solid line].\n",
 			Ctrl->W.pen[2].width, Ctrl->W.pen[2].rgb[0], Ctrl->W.pen[2].rgb[1], Ctrl->W.pen[2].rgb[2]);
 		fprintf (stderr, "\t     Requires -N to take effect.\n");
 		GMT_explain_option ('X');
@@ -441,7 +441,7 @@ int main (int argc, char **argv)
 				error++;
 			}
 		}
-		if (n_drape == 3 && !Ctrl->Q.mode == GRDVIEW_IMAGE) {
+		if (n_drape == 3 && Ctrl->Q.mode != GRDVIEW_IMAGE) {
 			fprintf (stderr, "%s: R/G/B drape requires -Qi option\n", GMT_program);
 			error++;
 		}
@@ -478,12 +478,12 @@ int main (int argc, char **argv)
 		GMT_read_cpt (Ctrl->C.file);
 		if (GMT_b_and_w) Ctrl->Q.monochrome = TRUE;
 	}
-#ifdef GMT_CPT2	
+#ifdef GMT_CPT2
 	if (GMT_categorical && Ctrl->W.active) {
 		fprintf (stderr, "%s: GMT WARNING -W:  Categorical data (as implied by CPT file) does not have contours.  Check plot.\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-#endif	
+#endif
 	z_project.view_azimuth = Ctrl->E.azimuth;
 	z_project.view_elevation = Ctrl->E.elevation;
 	get_contours = ( (Ctrl->Q.mode == GRDVIEW_MESH && Ctrl->W.contour) || (Ctrl->Q.mode == GRDVIEW_SURF && GMT_n_colors > 1) );
@@ -506,7 +506,7 @@ int main (int argc, char **argv)
 
 	if (Ctrl->G.active) {
 		for (i = 0; i < n_drape; i++) GMT_err_fail (GMT_read_grd_info (Ctrl->G.file[i], &d_head[i]), Ctrl->G.file[i]);
-		two = 2; 
+		two = 2;
 	}
 
 	GMT_boundcond_init (&edgeinfo);
@@ -851,7 +851,7 @@ int main (int argc, char **argv)
 		GMT_free ((void *) xval);
 		GMT_free ((void *) yval);
 	}
-	
+
 	if (Ctrl->Q.mode == GRDVIEW_IMAGE) {	/* compute image */
 		GMT_LONG nx_i, ny_i, kk, ip, jp, min_i, max_i, min_j, max_j, dist, node, nm_i, nm_drape, layers, last_i, last_j, p;
 		GMT_LONG *top_jp = VNULL, *bottom_jp = VNULL, *ix, *iy;
@@ -986,7 +986,7 @@ int main (int argc, char **argv)
 						if (!pixel_inside (ip, jp, ix, iy, bin, bin_inc)) continue;
 						/* These pixels are part of the current tile */
 						if (no_nans) {	/* Update clip mask */
-							if (jp > top_jp[ip]) top_jp[ip] = jp; 
+							if (jp > top_jp[ip]) top_jp[ip] = jp;
 							if (jp < bottom_jp[ip]) bottom_jp[ip] = jp;
 						}
 
@@ -1008,7 +1008,7 @@ int main (int argc, char **argv)
 									bad++;
 							}
 							if (bad) continue;	/* We don't want to blend in the (typically) gray NaN colors with the others. */
-							
+
 							dist = quick_idist (ip, jp, ix[node], iy[node]);
 							if (dist == 0) {	/* Only need this corner value */
 								done = TRUE;
@@ -1201,10 +1201,10 @@ int main (int argc, char **argv)
 
 				X_vert[0] = X_vert[3] = x_left;	X_vert[1] = X_vert[2] = x_right;
 				Y_vert[0] = Y_vert[1] = y_bottom;	Y_vert[2] = Y_vert[3] = y_top;
-				
+
 				/* Also get z-values at the 4 nodes.  Because some nodes may have been adjusted by small during
 				 * the contouring stage we need to make the same adjustments below */
-				
+
 				for (k = 0; k < 4; k++) Z_vert[k] = zgrd[bin+bin_inc[k]];	/* First a straight copy */
 
 				if (get_contours && binij[bin].first_cont) {	/* Contours go thru here */
@@ -1225,7 +1225,7 @@ int main (int argc, char **argv)
 						Z_vert[k] += (float)this_cont->value;
 					}
 					/* Here, Z_vert reflects what the grid was when contouring was determined */
-					
+
 					if (saddle) {	/* Must deal with this separately */
 
 						this_point = this_cont->first_point;
@@ -1470,7 +1470,7 @@ int main (int argc, char **argv)
 
 					/* Take the color corresponding to the average value of the four corners */
 					z_ave = 0.25 * (Z_vert[0] + Z_vert[1] + Z_vert[2] + Z_vert[3]);
-						
+
 					/* Now paint the polygon piece */
 
 					for (k = 0; k < 4; k++) GMT_geoz_to_xy (X_vert[k], Y_vert[k], (double)(topo[ij+ij_inc[k]]), &xmesh[k], &ymesh[k]);
@@ -1486,7 +1486,7 @@ int main (int argc, char **argv)
 		GMT_free ((void *) vcont);
 	}
 
-	if (Ctrl->W.pen[1].texture || Ctrl->W.pen[0].texture) ps_setdash (CNULL, 0);
+	ps_setdash (CNULL, 0);
 
 	if (project_info.z_pars[0] == 0.0) GMT_map_clip_off();
 
@@ -1766,9 +1766,9 @@ GMT_LONG GMT_rgb_is_nan_rgb (int rgb[])
 
 void *New_grdview_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDVIEW_CTRL *C;
-	
+
 	C = (struct GRDVIEW_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDVIEW_CTRL), "New_grdview_Ctrl");
-	
+
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->E.azimuth = 180.0;
 	C->E.elevation = 90.0;
@@ -1784,8 +1784,8 @@ void *New_grdview_Ctrl () {	/* Allocate and initialize a new control structure *
 
 void Free_grdview_Ctrl (struct GRDVIEW_CTRL *C) {	/* Deallocate control structure */
 	GMT_LONG i;
-	if (C->C.file) free ((void *)C->C.file);	
-	for (i = 0; i < 3; i++) if (C->G.file[i]) free ((void *)C->G.file[i]);	
-	if (C->I.file) free ((void *)C->I.file);	
-	GMT_free ((void *)C);	
+	if (C->C.file) free ((void *)C->C.file);
+	for (i = 0; i < 3; i++) if (C->G.file[i]) free ((void *)C->G.file[i]);
+	if (C->I.file) free ((void *)C->I.file);
+	GMT_free ((void *)C);
 }
