@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
-*	$Id: mapproject.c 10289 2014-12-28 21:17:06Z pwessel $
+*	$Id: mapproject.c 10318 2015-07-01 01:58:57Z pwessel $
 *
 *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
 *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -522,14 +522,19 @@ int main (int argc, char **argv)
 			xmax /= project_info.x_scale;
 			ymin /= project_info.y_scale;
 			ymax /= project_info.y_scale;
+			if (unit) {	/* Change the 1:1 unit used */
+				xmin *= fwd_scale;
+				xmax *= fwd_scale;
+				ymin *= fwd_scale;
+				ymax *= fwd_scale;
+			}
+		}
+		else {	/* Convert inches to chosen MEASURE */
+			xmin *= inch_to_unit;
+			xmax *= inch_to_unit;
+			ymin *= inch_to_unit;
+			ymax *= inch_to_unit;
 		}
-
-		/* Convert inches to chosen MEASURE */
-		xmin *= inch_to_unit;
-		xmax *= inch_to_unit;
-		ymin *= inch_to_unit;
-		ymax *= inch_to_unit;
-
 		if (shift_xy) {
 			xmin += Ctrl->C.easting;
 			xmax += Ctrl->C.easting;
