@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *    $Id: psmeca.c 10289 2014-12-28 21:17:06Z pwessel $
+ *    $Id: psmeca.c 10331 2015-10-29 19:41:56Z pwessel $
  *
  *    Copyright (c) 1996-2015 by G. Patau
  *    Distributed under the GNU Public Licence
@@ -618,9 +618,11 @@ int main (int argc, char **argv)
 
 	    /* Immediately skip locations outside of the map area */
 
-            xy[ix] = atof (col[0]);
-            xy[iy] = atof (col[1]);
-            
+            if ((GMT_scanf (col[0], GMT_io.in_col_type[ix], &xy[ix]) == GMT_IS_NAN) || (GMT_scanf (col[1], GMT_io.in_col_type[iy], &xy[iy]) == GMT_IS_NAN)) {
+                fprintf (stderr, "%s: Record had bad x and/or y coordinates, must exit)\n", GMT_program);
+	        exit (EXIT_FAILURE);
+            }
+          
             if (skip_if_outside) {
                 GMT_map_outside (xy[0], xy[1]);
                 if (GMT_abs (GMT_x_status_new) > 1 || GMT_abs (GMT_y_status_new) > 1) continue;
@@ -643,11 +645,15 @@ int main (int argc, char **argv)
 
             if (read_cmt) {
                 meca.NP1.str = atof(col[2+new]);
+		if (meca.NP1.str > 180.0) meca.NP1.str -= 360.0; else if (meca.NP1.str < -180.0) meca.NP1.str += 360.0;		/* Strike must be in -180/+180 range*/
                 meca.NP1.dip = atof(col[3+new]);
                 meca.NP1.rake = atof(col[4+new]);
+ 		if (meca.NP1.rake > 180.0) meca.NP1.rake -= 360.0; else if (meca.NP1.rake < -180.0) meca.NP1.rake += 360.0;	/* Rake must be in -180/+180 range*/
                 meca.NP2.str = atof(col[5+new]);
+		if (meca.NP2.str > 180.0) meca.NP2.str -= 360.0; else if (meca.NP2.str < -180.0) meca.NP2.str += 360.0;		/* Strike must be in -180/+180 range*/
                 meca.NP2.dip = atof(col[6+new]);
                 meca.NP2.rake = atof(col[7+new]);
+		if (meca.NP2.rake > 180.0) meca.NP2.rake -= 360.0; else if (meca.NP2.rake < -180.0) meca.NP2.rake += 360.0;	/* Rake must be in -180/+180 range*/
                 meca.moment.mant = atof(col[8+new]);
                 meca.moment.exponent = atoi(col[9+new]);
                 if (meca.moment.exponent == 0) meca.magms = atof(col[8+new]);
@@ -655,8 +661,10 @@ int main (int argc, char **argv)
 	    
 	    else if (read_aki) {
                 meca.NP1.str = atof(col[2+new]);
+		if (meca.NP1.str > 180.0) meca.NP1.str -= 360.0; else if (meca.NP1.str < -180.0) meca.NP1.str += 360.0;		/* Strike must be in -180/+180 range*/
                 meca.NP1.dip = atof(col[3+new]);
                 meca.NP1.rake = atof(col[4+new]);
+		if (meca.NP1.rake > 180.0) meca.NP1.rake -= 360.0; else if (meca.NP1.rake < -180.0) meca.NP1.rake += 360.0;	/* Rake must be in -180/+180 range*/
                 meca.magms = atof(col[5+new]);    
 
                 meca.moment.exponent = 0;
@@ -665,8 +673,10 @@ int main (int argc, char **argv)
 	    
 	    else if (read_planes) {
                 meca.NP1.str = atof(col[2+new]);
+		if (meca.NP1.str > 180.0) meca.NP1.str -= 360.0; else if (meca.NP1.str < -180.0) meca.NP1.str += 360.0;		/* Strike must be in -180/+180 range*/
                 meca.NP1.dip = atof(col[3+new]);
                 meca.NP2.str = atof(col[4+new]);
+		if (meca.NP2.str > 180.0) meca.NP2.str -= 360.0; else if (meca.NP2.str < -180.0) meca.NP2.str += 360.0;		/* Strike must be in -180/+180 range*/
                 fault = atof(col[5+new]);
                 meca.magms = atof(col[6+new]);
 
@@ -746,8 +756,10 @@ Definition of scalar moment.
 	    /* If option -C is used, read the new position */
 
             if (read_change_position) {
-                xynew[ix] = atof(col[last-1+new]);
-                xynew[iy] = atof(col[last+new]);
+ 	        if ((GMT_scanf (col[last-1+new], GMT_io.in_col_type[ix], &xynew[ix]) == GMT_IS_NAN) || (GMT_scanf (col[last+new], GMT_io.in_col_type[iy], &xynew[iy]) == GMT_IS_NAN)) {
+	            fprintf (stderr, "%s: Record had bad newX and/or newYcoordinates, must exit\n", GMT_program);
+		    exit (EXIT_FAILURE);
+	        }
                 if (fabs(xynew[ix]) > EPSIL || fabs(xynew[iy]) > EPSIL) {
                     GMT_setpen(&cpen);
                     GMT_geo_to_xy(xynew[0], xynew[1], &plot_xnew, &plot_ynew);
@@ -903,7 +915,7 @@ Definition of scalar moment.
     
     ps_setpaint (gmtdefs.basemap_frame_rgb);
 
-    if (pen.texture) ps_setdash (CNULL, 0);
+    if (pen.texture[0]) ps_setdash (CNULL, 0);
     
     GMT_map_basemap ();
 
