@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *    $Id: pspolar.c 10289 2014-12-28 21:17:06Z pwessel $ 
+ *    $Id: pspolar.c 10329 2015-10-26 23:31:44Z pwessel $ 
  *
  *    Copyright (c) 1996-2015 by G. Patau
  *    Distributed under the GNU Public Licence
@@ -633,7 +633,7 @@ int main (int argc, char **argv)
 
     GMT_world_map = old_GMT_world_map;
     
-    if (pen.texture) ps_setdash (CNULL, 0);
+    if (pen.texture[0]) ps_setdash (CNULL, 0);
 
     GMT_map_basemap ();
 
