@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *    $Id: psvelo.c 10289 2014-12-28 21:17:06Z pwessel $
+ *    $Id: psvelo.c 10329 2015-10-26 23:31:44Z pwessel $
  *
  *    Copyright (c) 1996-2015 by G. Patau
  *    Distributed under the GNU Public Licence
@@ -472,7 +472,7 @@ int main (int argc, char **argv)
 
 	if (skip_if_outside) GMT_map_clip_off ();
 
-	if (pen.texture) ps_setdash (CNULL, 0);
+	if (pen.texture[0]) ps_setdash (CNULL, 0);
 
 	GMT_map_basemap ();
 
