@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: ps2raster.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: ps2raster.c 10320 2015-08-06 07:53:05Z remko $
  *
  *	Copyright (c) 2006-2015 by J. Luis
  *	See README file for copying and redistribution conditions.
@@ -184,15 +184,15 @@ int main (int argc, char **argv) {
 
 	void *New_ps2raster_Ctrl (), Free_ps2raster_Ctrl (struct PS2RASTER_CTRL *C);
 	GMT_LONG parse_GE_settings (char *arg, struct PS2RASTER_CTRL *C);
-	
+
 	Ctrl = (struct PS2RASTER_CTRL *)New_ps2raster_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	/* Parameters for all the formats available */
 
-	gs_params = "-q -dSAFER -dNOPAUSE -dBATCH -dUseFlateCompression=true -dPDFSETTINGS=/prepress -dEmbedAllFonts=true -dSubsetFonts=true -dMonoImageFilter=/FlateEncode -dAutoFilterGrayImages=false -dGrayImageFilter=/FlateEncode -dAutoFilterColorImages=false -dColorImageFilter=/FlateEncode";
+	gs_params = "-q -dSAFER -dNOPAUSE -dBATCH -dPDFSETTINGS=/prepress -dDownsampleColorImages=false -dDownsampleGrayImages=false -dDownsampleMonoImages=false -dUseFlateCompression=true -dEmbedAllFonts=true -dSubsetFonts=true -dMonoImageFilter=/FlateEncode -dAutoFilterGrayImages=false -dGrayImageFilter=/FlateEncode -dAutoFilterColorImages=false -dColorImageFilter=/FlateEncode";
 	gs_BB = "-q -dSAFER -dNOPAUSE -dBATCH -sDEVICE=bbox"; /* -r defaults to 4000, see http://pages.cs.wisc.edu/~ghost/doc/cvs/Devices.htm#Test */
 	memset ((void *)gs_extra, 0, BUFSIZ);
-	
+
 	/* Check and interpret the command line arguments */
 
 	GMT_program = argv[0];
@@ -255,7 +255,7 @@ int main (int argc, char **argv) {
 						fprintf (stderr, "%s: GMT ERROR: Unrecognized option %s\n", GMT_program, argv[i]);
 						error = TRUE;
 						continue;
-						
+
 					}
 					Ctrl->Q.on[mode] = TRUE;
 					Ctrl->Q.bits[mode] = (argv[i][3]) ? atoi (&argv[i][3]) : 4;
@@ -449,7 +449,7 @@ int main (int argc, char **argv) {
 		Ctrl->F.active = FALSE;
 	}
 
-	if (Ctrl->W.kml && !(Ctrl->T.device == GS_DEV_JPG || Ctrl->T.device == GS_DEV_JPGG || Ctrl->T.device == GS_DEV_TIF || 
+	if (Ctrl->W.kml && !(Ctrl->T.device == GS_DEV_JPG || Ctrl->T.device == GS_DEV_JPGG || Ctrl->T.device == GS_DEV_TIF ||
 				Ctrl->T.device == GS_DEV_TIFG || Ctrl->T.device == GS_DEV_PNG ||
 				Ctrl->T.device == GS_DEV_TPNG || Ctrl->T.device == GS_DEV_PNGG) ) {
 		fprintf (stderr, "%s: WARNERROR: As far as we know selected raster type is unsuported by GE\n", GMT_program);
@@ -554,7 +554,7 @@ int main (int argc, char **argv) {
 			sprintf (BB_file, "%s/ps2raster_%ldc.bb", Ctrl->D.dir, (GMT_LONG)getpid());
 			psfile_to_use = (Ctrl->A.strip) ? no_U_file : ((clean_PS_file) ? clean_PS_file : ps_file);
 			/* sprintf (cmd, "%s%s %s %s %s 2> %s", at_sign, Ctrl->G.file, gs_BB, gs_extra, psfile_to_use, BB_file); */
-			sprintf (cmd, "%s%s %s \'%s\' 2> %s", at_sign, Ctrl->G.file, gs_BB, psfile_to_use, BB_file);
+			sprintf (cmd, "%s%s %s \"%s\" 2> %s", at_sign, Ctrl->G.file, gs_BB, psfile_to_use, BB_file);
 			sys_retval = system (cmd);		/* Execute the command that computes the tight BB */
 			if (sys_retval) {
 				fprintf (stderr, "%s: System call [%s] returned error %d.\n", GMT_program, cmd, sys_retval);
@@ -577,7 +577,7 @@ int main (int argc, char **argv) {
 						sprintf (tmp_file, "%s/", Ctrl->D.dir);
 						strncat (tmp_file, &ps_file[pos_file], (size_t)(pos_ext - pos_file));
 						strcat (tmp_file, ext[Ctrl->T.device]);
-						sprintf (cmd, "%s%s %s %s -sDEVICE=%s -g1x1 -r%ld -sOutputFile=\'%s\' -f\'%s\'", 
+						sprintf (cmd, "%s%s %s %s -sDEVICE=%s -g1x1 -r%ld -sOutputFile=\"%s\" -f\"%s\"",
 							at_sign, Ctrl->G.file, gs_params, gs_extra, device[Ctrl->T.device],
 							Ctrl->E.dpi, tmp_file, ps_file);
 						sys_retval = system (cmd);		/* Execute the GhostScript command */
@@ -629,7 +629,7 @@ int main (int argc, char **argv) {
 		i = 0;
 		while ((fgets2 (line, BUFSIZ, fp) != NULL) && i < 20 && !(got_BB && got_HRBB && got_end)) {
 			i++;
-			if (!line[0] || line[0] != '%') 
+			if (!line[0] || line[0] != '%')
 				{ /* Skip empty and non-comment lines */ }
 			else if (!got_BB && (p = strstr (line, "%%BoundingBox:"))) {
 				sscanf (&p[14], "%s %s %s %s",c1,c2,c3,c4);
@@ -717,7 +717,7 @@ int main (int argc, char **argv) {
 						west  = atof(xx1);		east  = atof(xx2);
 						south = atof(yy1);		north = atof(yy2);
 						/* One further test. +xy was found, but have we geog coords? Check that */
-						if (!strcmp(proj4_name,"xy") && 
+						if (!strcmp(proj4_name,"xy") &&
 								(west >= -180) && ((east <= 360) && ((east - west) <= 360)) &&
 								(south >= -90) && (north <= 90) ) {
 							proj4_cmd = strdup("latlon");
@@ -727,12 +727,12 @@ int main (int argc, char **argv) {
 						}
 						else if (!strcmp(proj4_name,"xy") && Ctrl->W.warp) {	/* Do not operate on a twice unknown setting */
 							fprintf (stderr, "%s: WARNERROR: You requested an automatic geotiff generation, but "
-									"no recognized projection was used for the PS creation.\n", GMT_program); 
+									"no recognized projection was used for the PS creation.\n", GMT_program);
 						}
 					}
 					else if (Ctrl->W.kml) {
 						fprintf (stderr, "%s: WARNERROR: To GE images must be in geographical coords. Very likely "
-									"this won't work as you wish inside GE.\n", GMT_program); 
+									"this won't work as you wish inside GE.\n", GMT_program);
 					}
 				}
 			}
@@ -773,7 +773,7 @@ int main (int argc, char **argv) {
 				fprintf (fpo, "%%%%PageTrailer\n");
 				fprintf (fpo, "%s", line);
 
-				/* Write a GeoPDF registration info */ 
+				/* Write a GeoPDF registration info */
 
 				/* Allocate new control structures */
 				to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_Gdalread_Ctrl");
@@ -812,9 +812,9 @@ int main (int argc, char **argv) {
 					fprintf (fpo, "\t\t\t/Type /Measure\n");
 					fprintf (fpo, "\t\t\t/Subtype /GEO\n");
 					fprintf (fpo, "\t\t\t/Bounds[0 0 0 1 1 1 1 0]\n");
-					fprintf (fpo, "\t\t\t/GPTS[%f %f %f %f %f %f %f %f]\n", 
+					fprintf (fpo, "\t\t\t/GPTS[%f %f %f %f %f %f %f %f]\n",
 						south, west, north, west, north, east, south, east);
-					fprintf (fpo, "\t\t\t/LPTS[%f %f %f %f %f %f %f %f]\n", 
+					fprintf (fpo, "\t\t\t/LPTS[%f %f %f %f %f %f %f %f]\n",
 						lptsX[0],lptsY[0], lptsX[1],lptsY[1], lptsX[2],lptsY[2], lptsX[3],lptsY[3]);
 					fprintf (fpo, "\t\t\t/GCS <<\n");
 					fprintf (fpo, "\t\t\t\t/Type /PROJCS\n");
@@ -862,7 +862,7 @@ int main (int argc, char **argv) {
 			strcat (out_file, ext[Ctrl->T.device]);
 			pix_w = (GMT_LONG)ceil (w * Ctrl->E.dpi / 72.0);
 			pix_h = (GMT_LONG)ceil (h * Ctrl->E.dpi / 72.0);
-			sprintf (cmd, "%s%s %s %s -sDEVICE=%s -g%ldx%ld -r%ld -sOutputFile=\'%s\' -f\'%s\'", 
+			sprintf (cmd, "%s%s %s %s -sDEVICE=%s -g%ldx%ld -r%ld -sOutputFile=\"%s\" -f\"%s\"",
 				at_sign, Ctrl->G.file, gs_params, gs_extra, device[Ctrl->T.device],
 				pix_w, pix_h, Ctrl->E.dpi, out_file, tmp_file);
 			sys_retval = system (cmd);		/* Execute the GhostScript command */
@@ -902,12 +902,12 @@ int main (int argc, char **argv) {
 			double x_inc, y_inc;
 			char *world_file, *wext, *s;
 
-			x_inc = (east  - west)  / pix_w; 
-			y_inc = (north - south) / pix_h; 
+			x_inc = (east  - west)  / pix_w;
+			y_inc = (north - south) / pix_h;
 			if (Ctrl->V.active) fprintf(stderr, "width = %ld\theight = %ld\tX res = %f\tY res = %f\n", pix_w, pix_h, x_inc, y_inc);
 
 			/* West and North of the world file contain the coordinates of the center of the pixel
-			   but our current values are of the NW corner of the pixel (pixel registration). So 
+			   but our current values are of the NW corner of the pixel (pixel registration). So
 			   we'll move halph pixel inward. */
 			west  += x_inc / 2;
 			north -= y_inc / 2;
@@ -940,12 +940,12 @@ int main (int argc, char **argv) {
 				fclose(fpw);
 				if (Ctrl->V.active) {
 					fprintf(stderr, "Wrote world file %s\n", world_file);
-					if (proj4_cmd) fprintf(stderr, "Proj4 definition: %s\n", proj4_cmd); 
+					if (proj4_cmd) fprintf(stderr, "Proj4 definition: %s\n", proj4_cmd);
 				}
-			
+
 			}
 
-			free ((void *)wext);	
+			free ((void *)wext);
 
 			if (Ctrl->W.warp && proj4_cmd && proj4_cmd[1] == 'p') {	/* We got a usable Proj4 string. Run it (if gdal is around) */
 				/* The true geotiff file will have the same base name plus a .tiff extension.
@@ -965,11 +965,11 @@ int main (int argc, char **argv) {
 					quiet = "";
 
 #ifdef WIN32
-				sprintf (cmd, "gdal_translate -a_srs \"%s\" -co COMPRESS=LZW -co TILED=YES %s \'%s\' \'%s\'", 
-						proj4_cmd, quiet, out_file, world_file); 
+				sprintf (cmd, "gdal_translate -a_srs \"%s\" -co COMPRESS=LZW -co TILED=YES %s \"%s\" \"%s\"",
+						proj4_cmd, quiet, out_file, world_file);
 #else
-				sprintf (cmd, "gdal_translate -a_srs '%s' -co COMPRESS=LZW -co TILED=YES %s \'%s\' \'%s\'", 
-						proj4_cmd, quiet, out_file, world_file); 
+				sprintf (cmd, "gdal_translate -a_srs '%s' -co COMPRESS=LZW -co TILED=YES %s \"%s\" \"%s\"",
+						proj4_cmd, quiet, out_file, world_file);
 #endif
 				free(proj4_cmd);
 				sys_retval = system (cmd);		/* Execute the gdal_translate command */
@@ -982,7 +982,7 @@ int main (int argc, char **argv) {
 			else if (Ctrl->W.warp && !proj4_cmd)
 				fprintf (stderr, "%s: Could not find the Proj4 command in the PS file. No conversion performed.\n", GMT_program);
 
-			GMT_free ((void *)world_file);	
+			GMT_free ((void *)world_file);
 		}
 
 		else if ( Ctrl->W.kml ) {	/* Write a basic kml file */
@@ -1055,9 +1055,9 @@ int main (int argc, char **argv) {
 				if (Ctrl->V.active) {
 					fprintf(stderr, "Wrote KML file %s\n", kml_file);
 				}
-			
+
 			}
-			GMT_free ((void *)kml_file);	
+			GMT_free ((void *)kml_file);
 		}
 
 		else if (Ctrl->W.active && !found_proj) {
@@ -1078,11 +1078,11 @@ int main (int argc, char **argv) {
 GMT_LONG parse_GE_settings (char *arg, struct PS2RASTER_CTRL *C)
 {
 	/* Syntax: -W[+g][+k][+t<doctitle>][+n<layername>][+a<altmode>][+f<fademin>/<fademax>][+l<lodmin>/<lodmax>][+u<URL>] */
-	
+
 	GMT_LONG error = FALSE;
 	GMT_LONG pos = 0;
 	char txt[BUFSIZ], p[BUFSIZ];
-	
+
 	C->W.active = TRUE;
 	strcpy (txt, arg);
 	while (!error && (GMT_strtok (txt, "+", &pos, p))) {
