@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: psxyz.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: psxyz.c 10322 2015-10-07 13:38:30Z remko $
  *
  *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -109,7 +109,7 @@ int main (int argc, char **argv)
 	GMT_LONG i, n, n_alloc = 0, n_total_read = 0, j, n_files = 0, pos2x, pos2y;
 	GMT_LONG fno, n_cols_start = 3, n_args, n_fields, this_outline;
 	GMT_LONG three, four, five, n_required = 3, n_expected = 0, change;
-	
+
 	int rgb[9];
 
 	double west = 0.0, east = 0.0, south = 0.0, north = 0.0, dim[3], DX, DY;
@@ -131,7 +131,7 @@ int main (int argc, char **argv)
 	void bary3D (double x, double y, double z, double base, double size, struct GMT_FILL *f, GMT_LONG outline);
 	void sort_on_distance (struct PSXYZ_DATA1 *data, GMT_LONG n);
 	void *New_psxyz_Ctrl (), Free_psxyz_Ctrl (struct PSXYZ_CTRL *C);
-	
+
 	argc = (int)GMT_begin (argc, argv);
 
 	Ctrl = (struct PSXYZ_CTRL *)New_psxyz_Ctrl ();	/* Allocate and initialize a new control structure */
@@ -149,7 +149,7 @@ int main (int argc, char **argv)
 	S.h_length = 0.12;
 	S.h_width = 0.1;
 	S.base = GMT_d_NaN;
-	
+
 	lux[0] = lux[1] = lux[2] = 0.0;	/* Default is no shading */
 
 	if ((S.u = gmtdefs.measure_unit) == GMT_CM) {
@@ -162,7 +162,7 @@ int main (int argc, char **argv)
 		if (argv[i][0] == '-') {
 			switch(argv[i][1]) {
 				/* Common parameters */
-	
+
 				case 'B':
 				case 'H':
 				case 'J':
@@ -186,9 +186,9 @@ int main (int argc, char **argv)
 				case '\0':
 					error += (GMT_LONG)GMT_parse_common_options (argv[i], &west, &east, &south, &north);
 					break;
-		
+
 				/* Supplemental parameters */
-	
+
 				case 'C':
 					Ctrl->C.file = strdup (&argv[i][2]);
 					Ctrl->C.active = TRUE;
@@ -312,12 +312,12 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   Fronts: Give tickgap/ticklen[dir][type][:offset], where\n");
 		fprintf (stderr, "\t     dir    = Plot symbol to the l(eft) or r(ight) of front [Default is centered].\n");
 		fprintf (stderr, "\t     type   =  b(ox), c(ircle), f(ault), s(lip), t(riangle) [Default is f].\n");
-		fprintf (stderr, "\t       box      : square when centered, half-square otherwise.\n"); 
-		fprintf (stderr, "\t       circle   : full when centered, half-circle otherwise.\n"); 
-		fprintf (stderr, "\t       fault    : centered cross-tick or tick only in the <dir> direction.\n"); 
-		fprintf (stderr, "\t       slip     : left-lateral or right-lateral strike-slip arrows (centered is not defined).\n"); 
-		fprintf (stderr, "\t       triangle : diagonal square when centered, directed triangle otherwise.\n"); 
-		fprintf (stderr, "\t     offset = start plotting symbols when along-track distance equals offset [0].\n"); 
+		fprintf (stderr, "\t       box      : square when centered, half-square otherwise.\n");
+		fprintf (stderr, "\t       circle   : full when centered, half-circle otherwise.\n");
+		fprintf (stderr, "\t       fault    : centered cross-tick or tick only in the <dir> direction.\n");
+		fprintf (stderr, "\t       slip     : left-lateral or right-lateral strike-slip arrows (centered is not defined).\n");
+		fprintf (stderr, "\t       triangle : diagonal square when centered, directed triangle otherwise.\n");
+		fprintf (stderr, "\t     offset = start plotting symbols when along-track distance equals offset [0].\n");
 		fprintf (stderr, "\t   Kustom: append <symbolname> immediately after 'k'; this will look for <symbolname>.def in\n");
 		fprintf (stderr, "\t     the current directory, in $GMT_USERDIR, or in $GMT_SHAREDIR (in that order).\n");
 		GMT_list_custom_symbols ();
@@ -453,8 +453,8 @@ int main (int argc, char **argv)
 	lux[2] = fabs (z_project.sin_el);
 	tmp = MAX (lux[0], MAX (lux[1], lux[2]));
 	for (i = 0; i < 3; i++) lux[i] = (lux[i] / tmp) - 0.5;
-	
-	if ((Ctrl->C.active || current_fill.rgb[0]) >= 0 && (S.symbol == GMT_SYMBOL_COLUMN || S.symbol == GMT_SYMBOL_CUBE)) {	/* Modify the color for each facet */
+
+	if ((Ctrl->C.active || current_fill.rgb[0] >= 0) && (S.symbol == GMT_SYMBOL_COLUMN || S.symbol == GMT_SYMBOL_CUBE)) {	/* Modify the color for each facet */
 		for (i = 0; i < 3; i++) {
 			rgb[3*i] = current_fill.rgb[0];
 			rgb[3*i+1] = current_fill.rgb[1];
@@ -540,7 +540,7 @@ int main (int argc, char **argv)
 
 				while (GMT_REC_IS_SEG_HEADER && !GMT_REC_IS_EOF) {	/* Skip segment headers */
 					if (gmtdefs.verbose) ps_comment (GMT_io.segment_header);
-					
+
 					change = GMT_parse_multisegment_header (GMT_io.segment_header, Ctrl->C.active, &fill_active, &current_fill, &default_fill, &outline_active, &current_pen, &default_pen, default_outline);
 					if (Ctrl->I.active) {
 						GMT_illuminate (Ctrl->I.value, current_fill.rgb);
@@ -568,7 +568,7 @@ int main (int argc, char **argv)
 				}
 
 				/* If read_symbol is TRUE we must unto the dimension scaling for items that should have no scaling, e.g., angles */
-				
+
 				if (read_symbol) for (j = 0; j < S.n_nondim; j++) in[S.nondim_col[j]+get_rgb] *= GMT_u2u[GMT_INCH][S.u];	/* Undo scales since these are angles, not dimensions */
 
 				if (S.read_size) {
@@ -632,7 +632,7 @@ int main (int argc, char **argv)
 				if (S.user_unit) data1[n].flag |= 4;
 
 				/* Skip zero-size symbols */
-		
+
 				if (S.symbol != GMT_SYMBOL_POINT && S.symbol < GMT_SYMBOL_ELLIPSE && S.size_x <= 0.0) {
 					if (gmtdefs.verbose) fprintf (stderr, "%s: Warning: Symbol size <= 0.0 near line %ld (skipped)\n", GMT_program, n_total_read);
 					continue;
@@ -708,9 +708,9 @@ int main (int argc, char **argv)
 				if (read_symbol) n_expected = GMT_MAX_COLUMNS;
 			}
 			n_alloc = GMT_alloc_memory ((void **)&data1, 0, n, sizeof (struct PSXYZ_DATA1), GMT_program);
-	
+
 			/* Sort according to distance  from viewer */
-	
+
 			if (!Ctrl->Q.active) sort_on_distance (data1, n);
 
 			/* Now plot these symbols one at the time */
@@ -725,11 +725,11 @@ int main (int argc, char **argv)
 						if (S.shade3D) GMT_illuminate (lux[j], &rgb[3*j]);
 					}
 				}
-		
+
 				if (GMT_cpt_skip) continue;	/* Skip this because cpt says so */
 
 				if (data1[i].outline) GMT_setpen (&data1[i].p);
-		
+
 				switch (data1[i].symbol) {
 					case GMT_SYMBOL_NONE:
 						break;
@@ -963,7 +963,7 @@ int main (int argc, char **argv)
 				while (GMT_REC_IS_NEW_SEGMENT) {	/* Process multisegment header flags (or NaN gaps) */
 					if (GMT_REC_IS_SEG_HEADER) {
 						if (gmtdefs.verbose) ps_comment (GMT_io.segment_header);
-					
+
 						change = GMT_parse_multisegment_header (GMT_io.segment_header, Ctrl->C.active, &fill_active, &current_fill, &default_fill, &outline_active, &current_pen, &default_pen, default_outline);
 						if (Ctrl->I.active) {
 							GMT_illuminate (Ctrl->I.value, current_fill.rgb);
@@ -998,9 +998,9 @@ int main (int argc, char **argv)
 					n++;
 					n_fields = GMT_input (fp, &n_expected, &in);
 				}
-				
+
 				/* Done reading a segment */
-				
+
 				if (polygon) {  /* Explicitly close polygon */
 					if (n == n_alloc) n_alloc = GMT_alloc_memory ((void **)&data2, n, n_alloc, sizeof (struct PSXYZ_DATA2), GMT_program);
 					data2[n].x = data2[0].x;
@@ -1009,12 +1009,12 @@ int main (int argc, char **argv)
 					n++;
 				}
 				n_alloc = GMT_alloc_memory ((void **)&data2, n, n_alloc, sizeof (struct PSXYZ_DATA2), GMT_program);
-		
+
 				if (!GMT_cpt_skip) {
 					double *xp, *yp;
 					xp = (double *) GMT_memory (VNULL, (size_t)n, sizeof (double), GMT_program);
 					yp = (double *) GMT_memory (VNULL, (size_t)n, sizeof (double), GMT_program);
-		
+
 					if (polygon) {
 						for (i = 0; i < n; i++) GMT_geoz_to_xy (data2[i].x, data2[i].y, data2[i].z, &xp[i], &yp[i]);
 						GMT_fill (xp, yp, n, &current_fill, outline_active);
@@ -1057,7 +1057,7 @@ int main (int argc, char **argv)
 
 	if (clip_set) GMT_map_clip_off ();
 
-	if (current_pen.texture) ps_setdash (CNULL, 0);
+	ps_setdash (CNULL, 0);
 	if (project_info.three_D) GMT_vertical_axis (2);	/* Draw background axis */
 
 	ps_rotatetrans (z_project.xmin, z_project.ymin, 0.0);
@@ -1209,11 +1209,11 @@ int dist_compare (const void *a, const void *b)
 
 void *New_psxyz_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSXYZ_CTRL *C;
-	
+
 	C = (struct PSXYZ_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSXYZ_CTRL), "New_psxyz_Ctrl");
-	
+
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
-		
+
 	C->E.azimuth = 180.0;
 	C->E.elevation = 90.0;
 	GMT_init_pen (&C->W.pen, GMT_PENWIDTH);
@@ -1223,6 +1223,6 @@ void *New_psxyz_Ctrl () {	/* Allocate and initialize a new control structure */
 }
 
 void Free_psxyz_Ctrl (struct PSXYZ_CTRL *C) {	/* Deallocate control structure */
-	if (C->C.file) free ((void *)C->C.file);	
-	GMT_free ((void *)C);	
+	if (C->C.file) free ((void *)C->C.file);
+	GMT_free ((void *)C);
 }
