@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: sample1d.c 10173 2014-01-01 09:52:34Z pwessel $
+ *	$Id: sample1d.c 10289 2014-12-28 21:17:06Z pwessel $
  *
- *	Copyright (c) 1991-2014 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -419,38 +419,39 @@ int main (int argc, char **argv)
 				if (m == 0) fprintf (stderr, "%s: Warning: No output points for range %g to %g\n", GMT_program, col[Ctrl->T.col][0], col[Ctrl->T.col][n-1]);
 			}
 			else {	/* Generate evenly spaced grid */
+				GMT_LONG first_k, last_k;
+				double abs_inc, last_t;
 				if (!Ctrl->I.active) Ctrl->I.inc = col[Ctrl->T.col][1] - col[Ctrl->T.col][0];
 				if (Ctrl->I.active && (col[Ctrl->T.col][1] - col[Ctrl->T.col][0]) < 0.0 && Ctrl->I.inc > 0.0) Ctrl->I.inc = -Ctrl->I.inc;	/* For monotonically decreasing data */
+				first_k = (Ctrl->I.inc > 0.0) ? 0 : n-1;	/* Index of point with earliest time */
+				last_k  = (Ctrl->I.inc > 0.0) ? n-1 : 0;	/* Index of point with latest time */
+				abs_inc = fabs (Ctrl->I.inc);
 				if (!Ctrl->S.active) {
-					if (Ctrl->I.inc > 0.0) {
-						Ctrl->S.start = floor (col[Ctrl->T.col][0] / Ctrl->I.inc) * Ctrl->I.inc;
-						if (Ctrl->S.start < col[Ctrl->T.col][0]) Ctrl->S.start += Ctrl->I.inc;
-					}
-					else {
-						Ctrl->S.start = ceil (col[Ctrl->T.col][0] / (-Ctrl->I.inc)) * (-Ctrl->I.inc);
-						if (Ctrl->S.start > col[Ctrl->T.col][0]) Ctrl->S.start += Ctrl->I.inc;
-					}
+					Ctrl->S.start = floor (col[Ctrl->T.col][first_k] / abs_inc) * abs_inc;
+					if (Ctrl->S.start < col[Ctrl->T.col][first_k]) Ctrl->S.start += abs_inc;
 				}
-				m = m_alloc = irint (fabs((col[Ctrl->T.col][n-1] - Ctrl->S.start) / Ctrl->I.inc)) + 1;
+				last_t = col[Ctrl->T.col][last_k];
+				/* So here, Ctrl->S.start holds to smallest t value and last_t holds the largest t_value, regardless of inc sign */
+				m = m_alloc = irint (fabs((last_t - Ctrl->S.start) / abs_inc)) + 1;
 				t_out = (double *) GMT_memory ((void *)t_out, (size_t)m_alloc, sizeof (double), GMT_program);
-				t_out[0] = Ctrl->S.start;
 				i = 1;
 				if (Ctrl->I.inc > 0.0) {
-					while (i < m && (tt = Ctrl->S.start + i * Ctrl->I.inc) <= col[Ctrl->T.col][n-1]) {
+					t_out[0] = Ctrl->S.start;
+					while (i < m && (tt = Ctrl->S.start + i * Ctrl->I.inc) <= last_t) {
 						t_out[i] = tt;
 						i++;
 					}
+					if (fabs (t_out[i-1]-last_t) < GMT_SMALL) t_out[i-1] = last_t;	/* Fix roundoff */
 				}
 				else {
-					while (i < m && (tt = Ctrl->S.start + i * Ctrl->I.inc) >= col[Ctrl->T.col][n-1]) {
+					t_out[0] = last_t;
+					while (i < m && (tt = last_t + i * Ctrl->I.inc) >= Ctrl->S.start) {
 						t_out[i] = tt;
 						i++;
 					}
+					if (fabs (t_out[i-1]-Ctrl->S.start) < GMT_SMALL) t_out[i-1] = Ctrl->S.start;	/* Fix roundoff */
 				}
 				m = i;
-				if (fabs (t_out[m-1]-col[Ctrl->T.col][n-1]) < GMT_SMALL) {	/* Fix roundoff */
-					t_out[m-1] = col[Ctrl->T.col][n-1];
-				}
 			}
 
 			if (nan_flag[Ctrl->T.col]) {
